/**
 * @file eeprom.h
 * @brief handles eeprom storage for persistent data
 *
 * Contains functions and definitions for reading and writing to eeprom
 *
 * @author Colony Project, Brad Neuman
 */
 
 #ifndef _EEPROM_H_
 #define _EEPROM_H_
 
 #include <bom.h>
 
 #define EEPROM_ROBOT_ID_ADDR 0x10
 #define EEPROM_BOM_TYPE_ADDR 0x14
 
 /** @brief store a byte to eeproem
  *  @return 0 if success, nonzero on failure
  */
 int eeprom_put_byte(unsigned int addr, unsigned char byte);
 
 /** @brief reads a byte from eeprom
  *
  *  Pass it thge address and a pointer to a byte where the byte at the
  *  address will be stored
  *
  *  @return 0 if successful (byte is set to the eeprom value at addr), 
  *  nonzero if there was a problem
   */
 int eeprom_get_byte(unsigned int addr, unsigned char *byte);
 
 /** @brief get stored robot ID
  *
  *  checks that EEPROM has been programed with an ID and returns it
  *
  *  @return the robot id, if it is stored. If it returns 0xFF it is probably invalid
  */
 unsigned char get_robotid(void);
  
   /** @brief get stored robot ID
  *
  * checks that EEPROM has been programed with an BOM type and returns it
  *
  *  @return the robot bom type as defined in bom.h, if it is stored. If it returns 0xFF it is probably invalid
  */
 unsigned char get_bom_type(void);
 
 #endif
