/**
 * Copyright (c) 2007 Colony Project
 * 
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without
 * restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following
 * conditions:
 * 
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 **/


/**
 * @file rangefinder.h
 * @brief Contains rangefinder declarations and functions
 * 
 * Contains functions and definitions for the use of
 * IR rangefinders.
 *
 * @author Colony Project, CMU Robotics Club
 **/

#ifndef _RANGEFINDER_H_
#define _RANGEFINDER_H_

/**
 * @addtogroup rangefinder
 * @{
 **/

/** @brief IR Rangefinder 1 **/
#define IR1 6
/** @brief IR Rangefinder 2 **/
#define IR2 5
/** @brief IR Rangefinder 3 **/
#define IR3 4
/** @brief IR Rangefinder 4 **/
#define IR4 3
/** @brief IR Rangefinder 5 **/
#define IR5 2
/** @brief smallest meaningful rangefinder reading (logarithmic scale) **/
#define MIN_IR_ADC8 20
/** @brief largest meaningful rangefinder reading (logarithmic scale) **/
#define MAX_IR_ADC8 133

/** @brief Initialize the rangefinders **/
void range_init(void);
/** @brief Read the distance from a rangefinder **/
int range_read_distance(int range_id);
/** @brief Convert logarithmic-scale distance readings to a linear scale **/
int linearize_distance(int value);

/** @} **/ //end addtogroup

#endif

