/**
 * Copyright (c) 2007 Colony Project
 * 
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without
 * restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following
 * conditions:
 * 
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 **/


/**
 * @file time.h
 * @brief Contains time-related functions and definitions
 *
 * Contains functions and definitions for dealing with time,
 * namely delay_ms and the realtime clock.
 *
 * @author Colony Project, CMU Robotics Club
 **/

#ifndef _TIME_H_
#define _TIME_H_

/*	Predefined times for prescale_opt in time.c.
	To make you own, know that a pulse is 1/16th of a second. You cannot get less than this. To get more, you need
	to know how many 16ths of a second are in the time you want. (Time_desired * 16 = prescaler_opt)
*/
/**
 * @addtogroup time
 * @{
 **/
/** @brief A sixteenth of a second **/
#define SIXTEENTH_SECOND 1
/** @brief An eighth of a second **/
#define EIGTH_SECOND 2
/** @brief A quarter of a second **/
#define QUARTER_SECOND 4
/** @brief Half of a second **/
#define HALF_SECOND	8
/** @brief One second **/
#define SECOND 16
/** @brief Two seconds **/
#define TWO_SECOND 32
/** @brief Four seconds **/
#define FOUR_SECOND 64

/** @brief Delay execution for the specified time **/
void delay_ms(int ms) ;
/** @brief Enable the realtime clock **/
void rtc_init(int prescale_opt, void (*rtc_func)(void));
/** @brief Reset the counter of the realtime clock **/
void rtc_reset(void);
/** @brief Get the value of the realtime clock. **/
int rtc_get(void);

/** @} **/

#endif

