/**
 * Copyright (c) 2007 Colony Project
 * 
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without
 * restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following
 * conditions:
 * 
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 **/

/**
 * @file queue.h
 * @brief A queue implementation
 * 
 * Implements a queue, a first in, first out data structure.
 *
 * @author Brian Coltin, Colony Project, CMU Robotics Club
 **/

#ifndef WIRELESS_QUEUE_H
#define WIRELESS_QUEUE_H

#ifndef ROBOT
#include <pthread.h>
#endif

struct node_def;

/**
 * @defgroup queue Queue
 * @brief A queue implementation
 * 
 * A queue implementation.
 *
 * @{
 **/

/**
 * @struct Queue
 * Represents a queue, a first in, first out data structure.
 **/
typedef struct
{
	/**
	 * The head of the queue, the next item to be removed.
	 **/
	struct node_def* head;
	/**
	 * The tail of the queue, the last item added.
	 **/
	struct node_def* tail;
	/**
	 * The number of elements in the queue.
	 **/
	int size;
	
#ifndef ROBOT
	pthread_mutex_t lock;
#endif
} Queue;

/** @brief Create a new queue **/
Queue* queue_create(void);
/** @brief Destroy a queue **/
void queue_destroy(Queue* q);
/** @brief Add an element to a queue **/
int queue_add(Queue* q, void* item);
/** @brief Remove an element from a queue **/
void* queue_remove(Queue* q);
/** @brief Remove all instances of a given element from a queue **/
void queue_remove_all(Queue* q, void* item);
/** @brief Get the size of a queue **/
int queue_size(Queue* q);
/** @brief Check if the queue is empty **/
int queue_is_empty(Queue* q);

/** @} **/


#endif
