/**
 * @file wl_basic.h
 * @brief High Level Wireless Packet Sending-Receiving Functions
 *
 * Abstracted wireless functionality for sending and receiving packets
 *
 * @author Christopher Mar, Colony Project, CMU Robotics Club
 **/

/**
 * @defgroup wl_basic Wireless Basic
 * @brief Wireless abstraction for easily sending and receing packets.
 *
 * A high level abstraction of the wireless library.
 *
 * This will allow you to easily send and receive packets.
 *
 * @{
 **/

#ifndef WL_BASIC_H
#define WL_BASIC_H

#include <wireless.h>

/** @brief default wireless group for basic sending and receiving packets **/
#define WL_BASIC_GROUP 8

/** @brief PacketGroupHandler struct for Basic Group **/
PacketGroupHandler wl_basic_group_handler;

/**
 * @brief struct that contains relevant packet information
 **/
struct PacketInfo {
    char new_flag;
    char type;
    int source;
    unsigned char* data;
    int length;
};

/**
 * @brief current packet information, correct after wl_basic_do()
 **/
struct PacketInfo current_packet;

/** @brief init wireless for Basic Group **/
int wl_basic_init( void (*handle_receive) (char type, int source, unsigned char* packet, int length) );
/** @brief init wireless for Basic Group with default packet handling **/
int wl_basic_init_default( void );
/** @brief internal function to register a packet handler function **/
void wl_basic_register_handler( void (*handle_receive) (char type, int source, unsigned char* packet, int length) );
/** @brief send a packet to a single robot in Basic Group **/
void wl_basic_send_robot_packet( char type, char* data, int len, int dest );
/** @brief send a packet to all robots in Basic Group **/
void wl_basic_send_global_packet( char type, char* data, int len );
/** @brief internal default packet handler if none is specified on init **/
void wl_basic_packet_receive_handler( char type, int source, unsigned char* packet, int length );
/** @brief wrapper for wl_do() to return packet data buffer **/
unsigned char* wl_basic_do_default( int *length );
/** @} **/ // end defgroup

#endif

