/**
 * Copyright (c) 2007 Colony Project
 * 
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without
 * restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following
 * conditions:
 * 
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 **/

/**
 * @file wl_defs.h
 * @brief Definitions for Wireless
 *
 * Contains definitions for wireless packet groups, packet types,
 * debugging information, etc.
 *
 * @author Brian Coltin, Colony Project, CMU Robotics Club
 **/

#ifndef WL_DEFS_H
#define WL_DEFS_H

//comment out this line if using a computer hooked up to an xbee
//#define ROBOT

//uncomment this line for debug information
//#define WL_DEBUG

// Packet Groups and Types

// Error group
#define WL_ERROR_GROUP 1

#define WL_ERROR_STRING_TYPE 1

// Token Ring group
#define WL_TOKEN_RING_GROUP 2

#define WL_TOKEN_PASS 1
#define WL_TOKEN_SENSOR_MATRIX 2
#define WL_TOKEN_BOM_ON 3
#define WL_TOKEN_JOIN 4
#define WL_TOKEN_JOIN_ACCEPT 5

// timing constants
#ifndef FIREFLY
#define BOM_DELAY 100
#else
#define BOM_DELAY 200
#endif

#define DEATH_DELAY 4
#define JOIN_DELAY 8

#ifdef WL_DEBUG

#ifdef ROBOT
#include <serial.h>
#endif

#ifdef ROBOT
#define WL_DEBUG_PRINT( s ) usb_puts( s )
#else
#define WL_DEBUG_PRINT( s ) printf( s )
#endif

#ifdef ROBOT
#define WL_DEBUG_PRINT_INT( i ) usb_puti(i)
#else
#define WL_DEBUG_PRINT_INT( i ) printf("%i", i)
#endif

#else

#define WL_DEBUG_PRINT( s )
#define WL_DEBUG_PRINT_INT( i )

#endif

#endif

