/**
 * Copyright (c) 2007 Colony Project
 * 
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without
 * restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 **/

/**
 * @file wl_error_group.h
 * @brief Error Packets
 *
 * A packet group for sending error packets.
 *
 * @author Brian Coltin, Colony Project, CMU Robotics Club
 **/

#ifndef WL_ERROR_GROUP_H
#define WL_ERROR_GROUP_H

/**
 * @file wl_error_group.h
 * @brief A packet group for error messages.
 *
 * A packet group for sending and receiving error
 * messages.
 *
 * @author Brian Coltin, Colony Project, CMU Robotics Club
 **/

/**
 * @defgroup wlerror Error Packets
 * @brief Functions for sending and receiving error packets
 * 
 * Functions for sending and receiving error packets.
 * 
 * @{
 **/

/**@brief Register this packet group with the wireless library **/
void wl_error_register(void);
/**@brief Unregister this packet group with the wireless library **/
void wl_error_unregister(void);
/**@brief Send a string in an error packet **/
void wl_error_send_string(char* str);

/** @} **/ // end defgroup

#endif
